import 'package:blip_ds/blip_ds.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';

class DSUserAvatar extends StatelessWidget {
  final String? text;
  final Uri? uri;
  final double radius;
  final Color backgroundColor;
  final Color textColor;

  const DSUserAvatar({
    super.key,
    this.text,
    this.uri,
    this.radius = 25.0,
    this.backgroundColor = DSColors.primaryGreensTrue,
    this.textColor = Colors.black,
  });

  @override
  Widget build(BuildContext context) => uri != null
      ? CachedNetworkImage(
          imageUrl: uri.toString(),
          imageBuilder: (_, image) => CircleAvatar(
            radius: radius,
            backgroundColor: backgroundColor,
            backgroundImage: image,
          ),
          progressIndicatorBuilder: (_, __, downloadProgress) {
            final size = Size.fromRadius(radius);

            return SizedBox(
              height: size.height,
              width: size.width,
              child: CircularProgressIndicator(
                value: downloadProgress.progress,
                strokeWidth: 1,
              ),
            );
          },
          errorWidget: (_, __, ___) => _defaultUserIcon,
        )
      : _defaultUserIcon;

  String get _initials {
    String initials = '';

    if ((text?.isNotEmpty ?? false) && (int.tryParse(text!) == null)) {
      initials =
          RegExp(text!.split(' ').length >= 2 ? r'\b[A-Za-z]' : r'[A-Za-z]')
              .allMatches(text!)
              .map((m) => m.group(0))
              .join()
              .toUpperCase();

      initials = initials.substring(0, initials.length >= 2 ? 2 : 1);
    }

    return initials;
  }

  CircleAvatar get _defaultUserIcon => (text?.isNotEmpty ?? false)
      ? CircleAvatar(
          radius: radius,
          backgroundColor: backgroundColor,
          child: Padding(
            padding: const EdgeInsets.all(2.0),
            child: int.tryParse(text!) == null
                ? DSBodyText(
                    _initials,
                    color: textColor,
                    overflow: TextOverflow.clip,
                    maxLines: 1,
                    textAlign: TextAlign.center,
                  )
                : const Icon(
                    DSIcons.user_defaut_outline,
                    color: DSColors.neutralLightSnow,
                    size: 20.0,
                  ),
          ),
        )
      : CircleAvatar(
          radius: radius,
          backgroundColor: backgroundColor,
          backgroundImage: const AssetImage(
            'assets/images/avatar-default.png',
            package: DSUtils.packageName,
          ),
        );
}
